@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2018 Joël Krähemann
+ * Copyright (C) 2005-2020 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -53,7 +53,6 @@ static gpointer ags_start_sequencer_parent_class = NULL;
 
 enum{
   PROP_0,
-  PROP_APPLICATION_CONTEXT,
 };
 
 GType
@@ -106,22 +105,7 @@ ags_start_sequencer_class_init(AgsStartSequencerClass *start_sequencer)
   gobject->finalize = ags_start_sequencer_finalize;
 
   /* properties */
-  /**
-   * AgsStartSequencer:application-context:
-   *
-   * The assigned #AgsApplicationContext
-   * 
-   * Since: 2.0.0
-   */
-  param_spec = g_param_spec_object("application-context",
-				   i18n_pspec("application context of start sequencer"),
-				   i18n_pspec("The application context of start sequencer task"),
-				   AGS_TYPE_APPLICATION_CONTEXT,
-				   G_PARAM_READABLE | G_PARAM_WRITABLE);
-  g_object_class_install_property(gobject,
-				  PROP_APPLICATION_CONTEXT,
-				  param_spec);
-
+  
   /* task */
   task = (AgsTaskClass *) start_sequencer;
 
@@ -131,7 +115,7 @@ ags_start_sequencer_class_init(AgsStartSequencerClass *start_sequencer)
 void
 ags_start_sequencer_init(AgsStartSequencer *start_sequencer)
 {
-  start_sequencer->application_context = NULL;
+  //empty
 }
 
 void
@@ -145,27 +129,6 @@ ags_start_sequencer_set_property(GObject *gobject,
   start_sequencer = AGS_START_SEQUENCER(gobject);
 
   switch(prop_id){
-  case PROP_APPLICATION_CONTEXT:
-    {
-      AgsApplicationContext *application_context;
-
-      application_context = (AgsApplicationContext *) g_value_get_object(value);
-
-      if(start_sequencer->application_context == application_context){
-	return;
-      }
-
-      if(start_sequencer->application_context != NULL){
-	g_object_unref(start_sequencer->application_context);
-      }
-
-      if(application_context != NULL){
-	g_object_ref(application_context);
-      }
-
-      start_sequencer->application_context = application_context;
-    }
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID(gobject, prop_id, param_spec);
     break;
@@ -183,11 +146,6 @@ ags_start_sequencer_get_property(GObject *gobject,
   start_sequencer = AGS_START_SEQUENCER(gobject);
 
   switch(prop_id){
-  case PROP_APPLICATION_CONTEXT:
-    {
-      g_value_set_object(value, start_sequencer->application_context);
-    }
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID(gobject, prop_id, param_spec);
     break;
@@ -200,12 +158,6 @@ ags_start_sequencer_dispose(GObject *gobject)
   AgsStartSequencer *start_sequencer;
 
   start_sequencer = AGS_START_SEQUENCER(gobject);
-
-  if(start_sequencer->application_context != NULL){
-    g_object_unref(start_sequencer->application_context);
-
-    start_sequencer->application_context = NULL;
-  }
   
   /* call parent */
   G_OBJECT_CLASS(ags_start_sequencer_parent_class)->dispose(gobject);
@@ -214,17 +166,9 @@ ags_start_sequencer_dispose(GObject *gobject)
 void
 ags_start_sequencer_finalize(GObject *gobject)
 {
-  AgsAudioLoop *audio_loop;
-  AgsThread *sequencer_thread;
+  AgsStartSequencer *start_sequencer;
 
-  AgsApplicationContext *application_context;
-  AgsSequencer *sequencer;
-
-  application_context = AGS_START_SEQUENCER(gobject)->application_context;  
-
-  if(application_context != NULL){    
-    g_object_unref(application_context);
-  }
+  start_sequencer = AGS_START_SEQUENCER(gobject);
 
   /* call parent */
   G_OBJECT_CLASS(ags_start_sequencer_parent_class)->finalize(gobject);
@@ -242,8 +186,10 @@ ags_start_sequencer_launch(AgsTask *task)
 
   start_sequencer = AGS_START_SEQUENCER(task);
 
-  application_context = start_sequencer->application_context;
+  application_context = ags_application_context_get_instance();
 
+  g_return_if_fail(AGS_IS_CONCURRENCY_PROVIDER(application_context));
+  
   /* get main loop */
   audio_loop = ags_concurrency_provider_get_main_loop(AGS_CONCURRENCY_PROVIDER(application_context));
 
@@ -272,21 +218,19 @@ ags_start_sequencer_launch(AgsTask *task)
 
 /**
  * ags_start_sequencer_new:
- * @application_context: the #AgsApplicationContext
  *
  * Creates an #AgsStartSequencer.
  *
  * Returns: an new #AgsStartSequencer.
  *
- * Since: 2.0.0
+ * Since: 3.0.0
  */
 AgsStartSequencer*
-ags_start_sequencer_new(AgsApplicationContext *application_context)
+ags_start_sequencer_new()
 {
   AgsStartSequencer *start_sequencer;
 
   start_sequencer = (AgsStartSequencer *) g_object_new(AGS_TYPE_START_SEQUENCER,
-						       "application-context", application_context,
 						       NULL);
 
   return(start_sequencer);
